@@ -5,7 +5,6 @@ Utility for all runtime interaction with variables in different scopes
 """
 from jaseci.utils.id_list import IdList
 from jaseci.jac.machine.jac_value import JacValue
-from jaseci.jac.machine.jac_value import jac_elem_wrap
 
 
 class JacScope:
@@ -38,11 +37,11 @@ class JacScope:
             self.action_sets[group] = act
 
     def set_agent_refs(self, cur_node, cur_walker):
-        self.local_scope["here"] = jac_elem_wrap(cur_node)
-        self.local_scope["visitor"] = jac_elem_wrap(cur_walker)
+        self.local_scope["here"] = cur_node
+        self.local_scope["visitor"] = cur_walker
 
     def inherit_agent_refs(self, src_scope, src_node):  # used for calls of abilities
-        self.local_scope["here"] = jac_elem_wrap(src_node)
+        self.local_scope["here"] = src_node
         self.local_scope["visitor"] = src_scope.local_scope["visitor"]
 
     def get_aganet_refs(self):
@@ -72,6 +71,5 @@ class JacScope:
             self.local_scope[name] = None
             return JacValue(self.parent, ctx=self.local_scope, name=name)
         if found:
-            found.unwrap()
             return found
         return None
