@@ -1,4 +1,5 @@
 import os
+import sys
 
 DEFAULT_MSG = "Skipping scheduled walker!"
 DEFAULT_URL = (
@@ -13,5 +14,10 @@ TASK_CONFIG = {
     "result_backend": DEFAULT_URL,
     "broker_connection_retry_on_startup": True,
     "task_track_started": True,
-    "kube": {},
+    "worker_redirect_stdouts": False,
 }
+
+
+if "python3 -m unittest" in sys.argv:
+    TASK_CONFIG["task_always_eager"] = True
+    TASK_CONFIG["task_store_eager_result"] = True
